########################################################################
# GNU Makefile demonstrating combination of C and assembly source files
# File Name: makefile
# All targets in the makefile are processed sequentially by SDCC
# To create the file ‘file.hex’ using GNU make, just execute ‘make’
########################################################################
# The following lines defines additional directories to search for include files
#INCLUDES := -I”C:\Your Directory\Lab3\”

#MODEL = --model-large
MODEL = --model-small

# The following line defines flags given to the SDCC C compiler
CFLAGS := -c --debug $(MODEL) $(INCLUDES)

# The following line defines flags given to the SDCC linker
# Non-specific: –code-loc 0x6000 –xram-loc 0xB000 –model-large
LFLAGS := --debug --code-loc 0x8100 --code-size 0x8000 --xram-loc 0xC000 --xram-size 0x4000 $(MODEL)

# The following line specifies the default target(s) to build
#all: file.hex

# The following line specifies the object files that are to be linked together
OBJECTS := $(FNM).rel Startup.rel

# The following lines define a rule that sends the object files through the linker to
# create file.ihx which then has to be processed by packihx to create file.hex
file.hex : $(OBJECTS)
	sdcc $(LFLAGS) $^
	packihx $(FNM).ihx > $(FNM).hex

# The following rule sends each C file through the preprocessor and creates the asm file
# that is then assembled to create the rel file.
%.rel : %.c
	sdcc $(CFLAGS) $<

# The following rule sends each asm file (Not the asm files created by SDCC as an
# intermediate output of the compilation process.) through the assembler to create a rel
# file.
%.rel : %.asd
	sdas8051 -plosgff $<

# The following rule will clean all the derived objects from your directory.  This will
# save you from accidentally tying ‘rm *’ if you are developing on a UNIX platform.
# Hinweis: zum löschen der Dateien "make clean" aufrufen.
clean:
	$(RM) $(FNM).lst $(FNM).asm $(FNM).bak $(FNM).sym
	$(RM) $(FNM).map $(FNM).omf $(FNM).adb $(FNM).cdb
	$(RM) $(FNM).mem $(FNM).rel $(FNM).lk  $(FNM).ihx
	$(RM) $(FNM).rst
